@@ -1,7 +1,8 @@
 from .tag import *
 from .nbt import *
+from .path import *
 from .schema import *
 from .literal.parser import *
 from .literal.serializer import *
 
-__version__ = '1.4.1'
+__version__ = "1.7.0"
